==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm
 */
@JsonPropertyOrder({ OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm.JSON_PROPERTY_REALM_ID })
@JsonTypeName("OperationResponse_assignmentOperation_configuration_actions_assignUserToRealm")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_REALM_ID = "realmId";
    private String realmId;

    public OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm() {
    }

    public OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm realmId(String realmId) {

        this.realmId = realmId;
        return this;
    }

    /**
     * Get realmId
     *
     * @return realmId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REALM_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRealmId() {
        return realmId;
    }

    @JsonProperty(JSON_PROPERTY_REALM_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRealmId(String realmId) {
        this.realmId = realmId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm operationResponseAssignmentOperationConfigurationActionsAssignUserToRealm = (OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm) o;
        return Objects.equals(this.realmId,
                operationResponseAssignmentOperationConfigurationActionsAssignUserToRealm.realmId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(realmId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm {\n");
        sb.append("    realmId: ").append(toIndentedString(realmId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm
 */
@JsonPropertyOrder({ OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm.JSON_PROPERTY_REALM_ID })
@JsonTypeName("OperationResponse_assignmentOperation_configuration_actions_assignUserToRealm")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_REALM_ID = "realmId";
    private String realmId;

    public OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm() {
    }

    public OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm realmId(String realmId) {

        this.realmId = realmId;
        return this;
    }

    /**
     * Get realmId
     *
     * @return realmId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REALM_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRealmId() {
        return realmId;
    }

    @JsonProperty(JSON_PROPERTY_REALM_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRealmId(String realmId) {
        this.realmId = realmId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm operationResponseAssignmentOperationConfigurationActionsAssignUserToRealm = (OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm) o;
        return Objects.equals(this.realmId,
                operationResponseAssignmentOperationConfigurationActionsAssignUserToRealm.realmId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(realmId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OperationResponseAssignmentOperationConfigurationActionsAssignUserToRealm {\n");
        sb.append("    realmId: ").append(toIndentedString(realmId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
